###DOmake.imet.page.plots - creates 24hr profile ps plot file of IMET data
##
## smsmith 26feb96 mlvl62 - based on S.Schierer plot_summary.data
##
## Modified: R.L.Moe    Jan97 Correct name of Web Directory.
#
# Assumes environmental variables CRUISE, DIRUWDATA and BINDIR are set.


### WEB PAGE-source cruise leg & define web dir
source /scgscg/files/CRUISE.LEG
# set WEB_DIR=/WEB_SITE/LEGS_database/CURRENT/$CRUISE/DAILY_PROFILES/IMET
set WEB_DIR=/Web_Site/LEGS_database/CURRENT/$CRUISE/DAILY_PROFILES/IMET

# Lower/Upper range values - change these as necessary:
set WNDS_RANGE     = 0./30.       ; set WNDS_TIC     = "10g5:rel. wind spd, m/s:"
set WNDD_RANGE     = 0./360.      ; set WNDD_TIC     = "90g90:rel. wind dir, \312:"
set BPRES_RANGE    =  950/1050    ; set BPRES_TIC    = "a20g10:bar-press., mb:"
set TEMPAIR_RANGE  = 0/40         ; set TEMPAIR_TIC  = "10g5f1:air-temp, \312C:"
set RADSHORT_RANGE = 0/1200       ; set RADSHORT_TIC = "200g200:rad-short, wt/sq.mt:"
set RADLONG_RANGE  = 280/310      ; set RADLONG_TIC  = "a10g5f1:rad-long, wt/sq.mt:"
# don't change this:
set HR_RANGE       = 0./24.       ; set HR_TIC       = "2g1::"
set PRECIP_RANGE   = 0/50         ; set PRECIP_TIC   = "10g10:precip., mm:"

if ($#argv < 1) then
   echo "usage: DOmake.imet.page.plot   <date.ext>"
   echo " (makes & prints postscript file named imet_10min_summary.<date.ext>.ps)"
   exit
endif

set PRINTr = qms

cd $DIRUWDATA/IMET

set DATE = $1

set IFN = imet_10min_summary.$DATE

# extract IMET values at 10 minute intervals
awk '  \
/^19/{  \
 if(substr($2,5,1) == "0")  \
 {   \
s11 =$1  \
s12 = substr($2,1,2) + substr($2,4,2)/60.  \
s13 = $3  \
s14 = $4  \
s15 = $5  \
s16 = $6  \
s17 = $7  \
s18 = $8  \
getline  \
print s11,s12,s13,s14,s15,s16,s17,s18,$0  \
 }  \
}  ' $DIRUWDATA/IMET/IMETinpf.$DATE \
 >! $IFN

if !( -e $IFN ) then
   echo Cannot find file $IFN \!  Exiting...
   exit
endif

###################################################

set PAGE_SIZE = letter

set OFN = $IFN.ps

if ("$PAGE_SIZE" == "letter") then
   set XLENGTH = 6.5
   set YLENGTH = 1.0
#  set XOFF1 = 1.2 ; set YOFF1 =  9.0
   set XOFF1 = 1.2 ; set YOFF1 =  9.10
   set XOFF2 = 0.0 ; set YOFF2 = -1.4
   set OPT    = " -P "
else if ("$PAGE_SIZE" == "E") then
   echo E-size not done yet...
   exit
else 
   echo Should not be here with PAGE_SIZE of $PAGE_SIZE...
   exit
endif

set TITLE1   = "IMET data  $CRUISE  $DATE"
set TITLE2   = ""

set SIZE     = "$XLENGTH"/"$YLENGTH"
set SIZE_REV = "$XLENGTH"/-"$YLENGTH"
set AXES     = WeSn

# put COL_WNDD back to col 6 when that value corrected in IMET data record.
set COL_HR = 2       ; set COL_WNDS = 5      ; set COL_WNDD = 8
set COL_BPRES = 9    ; set COL_TEMPAIR = 12  ; set COL_RADSHORT = 14
set COL_RADLONG = 15 ; set COL_PRECIP = 16

###################### start the postscript file ############################
pwd | psxy -H1 >! $OFN -R0/1/0/1 -JX1/1 -X0 -Y0 -K `echo "$OPT"`



###################### start 1st panel ######################################
set XOFF   = $XOFF1
set YOFF   = $YOFF1
set TITLE  = "$TITLE1"
set RANGE  = "$HR_RANGE"/"$WNDS_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$WNDS_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
set SYMB   = x0.05
psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

set COL1 = $COL_HR ; set COL2 = $COL_WNDS
cat $IFN | \
   awk '{ if ($1==">") print $0 ; else print $C1, $C2 }' C1=$COL1 C2=$COL2 | \
   awk '{ if ($2=="NaN") print ">" ; else print $0 }' | \
   awk 'BEGIN { PREV1 = "j<>j"} { if ($1 != PREV1) print $0 ; PREV1 = $1 }' | \
   cat >! 2col
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 
#psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M -S"$SYMB"

psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################


###################### start 2nd panel ######################################
set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/"$WNDD_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$WNDD_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

set COL1 = $COL_HR ; set COL2 = $COL_WNDD
cat $IFN | \
   awk '{ if ($1==">") print $0 ; else print $C1, $C2 }' C1=$COL1 C2=$COL2 | \
   awk '{ if ($2=="NaN") print ">" ; else print $0 }' | \
   awk 'BEGIN { PREV1 = "j<>j"} { if ($1 != PREV1) print $0 ; PREV1 = $1 }' | \
   cat >! 2col
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 

psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################


###################### start 3rd panel ######################################
set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/"$BPRES_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$BPRES_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

set COL1 = $COL_HR ; set COL2 = $COL_BPRES
cat $IFN | \
   awk '{ if ($1==">") print $0 ; else print $C1, $C2 }' C1=$COL1 C2=$COL2 | \
   awk '{ if ($2=="NaN") print ">" ; else print $0 }' | \
   awk 'BEGIN { PREV1 = "j<>j"} { if ($1 != PREV1) print $0 ; PREV1 = $1 }' | \
   cat >! 2col
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 

psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################


###################### start 4th panel ######################################
set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/"$TEMPAIR_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$TEMPAIR_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

set COL1 = $COL_HR ; set COL2 = $COL_TEMPAIR
cat $IFN | \
   awk '{ if ($1==">") print $0 ; else print $C1, $C2 }' C1=$COL1 C2=$COL2 | \
   awk '{ if ($2=="NaN") print ">" ; else print $0 }' | \
   awk 'BEGIN { PREV1 = "j<>j"} { if ($1 != PREV1) print $0 ; PREV1 = $1 }' | \
   cat >! 2col
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 

psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################


###################### start 5th panel ######################################
set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/"$RADSHORT_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$RADSHORT_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

set COL1 = $COL_HR ; set COL2 = $COL_RADSHORT
cat $IFN | \
   awk '{ if ($1==">") print $0 ; else print $C1, $C2 }' C1=$COL1 C2=$COL2 | \
   awk '{ if ($2=="NaN") print ">" ; else print $0 }' | \
   awk 'BEGIN { PREV1 = "j<>j"} { if ($1 != PREV1) print $0 ; PREV1 = $1 }' | \
   cat >! 2col
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 

psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################


###################### start 6th panel ######################################
set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/"$RADLONG_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$RADLONG_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

set COL1 = $COL_HR ; set COL2 = $COL_RADLONG
cat $IFN | \
   awk '{ if ($1==">") print $0 ; else print $C1, $C2 }' C1=$COL1 C2=$COL2 | \
   awk '{ if ($2=="NaN") print ">" ; else print $0 }' | \
   awk 'BEGIN { PREV1 = "j<>j"} { if ($1 != PREV1) print $0 ; PREV1 = $1 }' | \
   cat >! 2col
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 

psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
###################### end panel ############################################


###################### start 7th panel ######################################
set XOFF   = $XOFF2
set YOFF   = $YOFF2
set TITLE  = $TITLE2
set RANGE  = "$HR_RANGE"/"$PRECIP_RANGE"
set XTIC   = "$HR_TIC"
set YTIC   = "$PRECIP_TIC"
set TIC    = "$XTIC"/"$YTIC":."$TITLE":"$AXES"
psbasemap   >> $OFN -R"$RANGE" -JX"$SIZE" -X$XOFF -Y$YOFF -O -K `echo "$OPT"` -B0

set COL1 = $COL_HR ; set COL2 = $COL_PRECIP
cat $IFN | \
   awk '{ if ($1==">") print $0 ; else print $C1, $C2 }' C1=$COL1 C2=$COL2 | \
   awk '{ if ($2=="NaN") print ">" ; else print $0 }' | \
   awk 'BEGIN { PREV1 = "j<>j"} { if ($1 != PREV1) print $0 ; PREV1 = $1 }' | \
   cat >! 2col
psxy < 2col >> $OFN -R -JX -O -K `echo "$OPT"` -M 

#psbasemap   >> $OFN -R -JX -O -K `echo "$OPT"` -B"$TIC"
psbasemap   >> $OFN -R -JX -O -K -U/-0.5/-0.5/  `echo "$OPT"` -B"$TIC"
###################### end panel ############################################



pwd | psxy -H1 >> $OFN -R -JX -O `echo "$OPT"`
### finish off the postscript file ##########################################

#print the plot
lp -s -d$PRINTr $OFN

## WEB PAGE-convert ps file to gif and place in web dir
cp $OFN imet.ps
alchemy imet.ps imet.gif -g -Zc1 -Zd 100 100 >& /dev/null
cp imet.gif $WEB_DIR/$IFN.gif
/usr/bin/rm imet.{ps,gif}


/bin/rm -f $IFN
#end
